==> kv5500-0.2.tar.gz: kv5500-0.2/src/kv5500_video.hpp <==
/*****************************************************************************
 *
 *  kv5500_video - read a video from kv5500 like phone.
 *
 * Copyright (c) 2006 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_VIDEO_H
#define KV5500_VIDEO_H

#include "kv5500_file.hpp"

namespace KV5500 {

    class VideoInfoScanner : public FileInfoScanner {
    public:
        VideoInfoScanner();

    private:
        VideoInfoScanner(const VideoInfoScanner&);
        VideoInfoScanner& operator=(const VideoInfoScanner&);
    };

    class VideoGetFileScanner : public GetFileScanner {
    public:
        VideoGetFileScanner(unsigned int num);

    private:
        VideoGetFileScanner(const VideoGetFileScanner&);
        VideoGetFileScanner& operator=(const VideoGetFileScanner&);

        std::string GetFilename() const;
    };

    void GetVideoInfo(std::vector<FileInfo>& vec);
    void SaveVideoFile(unsigned int num);
}

#endif

==> kv5500-0.3.tar.gz: kv5500-0.3/src/kv5500_video.hpp <==
/*****************************************************************************
 *
 *  kv5500_video - read a video from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_VIDEO_H
#define KV5500_VIDEO_H

#include "kv5500_file.hpp"

namespace KV5500 {

    class VideoInfoScanner : public FileInfoScanner {
    public:
        VideoInfoScanner();

    private:
        VideoInfoScanner(const VideoInfoScanner&);
        VideoInfoScanner& operator=(const VideoInfoScanner&);
    };

    class VideoGetFileScanner : public GetFileScanner {
    public:
        VideoGetFileScanner(unsigned int num);

    private:
        VideoGetFileScanner(const VideoGetFileScanner&);
        VideoGetFileScanner& operator=(const VideoGetFileScanner&);

        std::string GetFilename() const;
    };

    bool GetVideoInfo(std::vector<FileInfo>& vec);
    bool SaveVideoFile(unsigned int num);
}

#endif
